@@ -155,7 +155,7 @@ def login(cli):
                 if network_group:
                     summary_table.append(['Network Resource Group', f"{summary_object['network_group']['name']} ({summary_object['network_group']['organizationShortName']}) with {summary_object['network_group']['networks_count']} networks"])
                 if network:
-                    summary_table.append(['Configured Network', f"{summary_object['network']['name']} ({summary_object['network']['region']}) is {summary_object['network']['productVersion']} and status {summary_object['network']['status']}"])
+                    summary_table.append(['Configured Network', f"{summary_object['network']['name']} - {summary_object['network']['productVersion']} - {summary_object['network']['status']}"])
                 if cli.config.general.borders:
                     table_borders = "presto"
                 else:
@@ -540,7 +540,7 @@ def get(cli, echo: bool = True, spinner: object = None):
                         cli.log.warn(f"using 'id' only, ignoring params: '{', '.join(query_keys)}'")
                     match = network.get_resource_by_id(type=cli.args.resource_type, id=cli.args.query['id'], accept=cli.args.accept)
                 else:
-                    matches = network.find_resources(type=cli.args.resource_type, accept=cli.args.accept, **cli.args.query)
+                    matches = network.find_resources(type=cli.args.resource_type, accept=cli.args.accept, params=cli.args.query)
                     if len(matches) == 1:
                         match = matches[0]
 
@@ -669,7 +669,7 @@ def list(cli, spinner: object = None):
             if cli.args.resource_type == "data-centers":
                 matches = network.find_edge_router_data_centers(**cli.args.query)
             else:
-                matches = network.find_resources(type=cli.args.resource_type, accept=cli.args.accept, **cli.args.query)
+                matches = network.find_resources(type=cli.args.resource_type, accept=cli.args.accept, params=cli.args.query)
 
     if len(matches) == 0:
         spinner.fail(f"Found no {cli.args.resource_type} by '{', '.join(query_keys)}'")
@@ -838,7 +838,7 @@ def delete(cli):
 @cli.argument("-p", "--prefix", default=f"{cli.prog_name}-demo", help="choose a network name prefix to identify all of your demos")
 @cli.argument("-j", "--jwt", action="store_boolean", default=True, help="save the one-time enroll token for each demo identity in the current directory")
 @cli.argument("-e", "--echo-name", arg_only=True, action="store_true", default=False, help="only echo a friendly network name then exit")
-@cli.argument("-s", "--size", default="small", help=argparse.SUPPRESS)   # troubleshoot scale-up instance size factor
+@cli.argument("-s", "--size", default="medium", help=argparse.SUPPRESS)   # troubleshoot scale-up instance size factor
 @cli.argument("-v", "--product-version", default="default", help="network product version: 'default', 'latest', or any active semver")
 @cli.argument("--provider", default="AWS", help="cloud provider for hosted edge routers", choices=DC_PROVIDERS)
 @cli.argument("--regions", dest="regions", default=["us-west-1"], nargs="+", help="provider regions for hosted edge routers")
