@@ -346,6 +346,8 @@ def find_generic_resources(url: str, headers: dict, embedded: str = None, proxie
     # only get requested page, else first page and all pages
     if params.get('page'):
         get_all_pages = False
+    elif resource_type.name == 'network-groups':
+        params['page'] = 1           # start at 1 instead of 0 to workaround https://netfoundry.atlassian.net/browse/MOP-17890
     else:
         params['page'] = 0
 
@@ -393,13 +395,11 @@ def find_generic_resources(url: str, headers: dict, embedded: str = None, proxie
             yield yield_page
 
             # then yield subsequent pages, if applicable
-            if get_all_pages:           # this is False if param 'page' or 'size' to stop recursion or get a single page
+            if get_all_pages and total_pages > 1:      # get_all_pages is False if param 'page' or 'size' to stop recursion and get a single page
+                next_range_lower, next_range_upper = params['page'] + 1, total_pages
                 if resource_type.name == 'network-groups':
-                    params['page'] = 1  # workaround API bug https://netfoundry.atlassian.net/browse/MOP-17890
-                    next_range_lower, next_range_upper = params['page'] + 2, total_pages + 1
-                else:
-                    next_range_lower, next_range_upper = params['page'] + 1, total_pages
-                for next_page in range(next_range_lower, next_range_upper):  # first page is 0 unless network-groups which are 1-based
+                    next_range_upper += 1              # network-groups pages are 1-based and so +1 upper limit
+                for next_page in range(next_range_lower, next_range_upper):
                     params['page'] = next_page
                     try:
                         # recurse
@@ -436,6 +436,7 @@ class Utility:
 
 
 NET_RESOURCES = dict()             # resources in network domain
+ZITI_NET_RESOURCES = dict()        # network resources that are backed 1:1 by a zitiId
 MUTABLE_NET_RESOURCES = dict()     # network resources that can be updated
 MUTABLE_RESOURCE_ABBREV = dict()   # unique abbreviations for ^
 EMBED_NET_RESOURCES = dict()       # network resources that may be fetched as embedded collections
@@ -484,9 +485,8 @@ class ResourceTypeParent:
 class ResourceType(ResourceTypeParent):
     """Typed resource type spec.
 
-    As close as I could get to a Go struct. This helps us to suggest possible
-    operations such as all resource types in the network domain that can be
-    mutated (C_UD).
+    This helps the CLI to suggest possible operations such as all resource
+    types in the network domain that can be mutated (C_UD).
     """
 
     name: str                                               # plural form as kebab-case e.g. edge-routers
@@ -509,6 +509,7 @@ class ResourceType(ResourceTypeParent):
     abbreviation: str = field(default='default')
     status_symbols: dict = field(default_factory=lambda: RESOURCE_STATUS_SYMBOLS)  # dictionary with three predictable keys: complete, progress, error, each a tuple associating status symbols with a state
     host: bool = field(default=False)                       # may have a managed host in NF cloud
+    ziti: bool = field(default=False)
 
     def __post_init__(self):
         """Compute and assign _embedded if not supplied and then check types in parent class."""
@@ -534,6 +535,8 @@ class ResourceType(ResourceTypeParent):
             if self.host:
                 HOSTABLE_NET_RESOURCES[self.name] = self
                 HOSTABLE_RESOURCE_ABBREV[self.abbreviation] = self
+            if self.ziti:
+                ZITI_NET_RESOURCES[self.name] = self
         return super().__post_init__()
 
 
@@ -554,6 +557,21 @@ RESOURCES = {
         status="state",
         status_symbols=PROCESS_STATUS_SYMBOLS,
     ),
+    'executions': ResourceType(
+        name='executions',
+        domain='network',
+        mutable=False,
+        embeddable=True,
+        status_symbols=PROCESS_STATUS_SYMBOLS,
+        abbreviation='ex',
+    ),
+    # 'processes': ResourceType(  # not a fully-fledged resource type because there is no "find processes" operation at this time
+    #     name='processes',
+    #     domain='network',
+    #     mutable=False,
+    #     embeddable=False,
+    #     status_symbols=PROCESS_STATUS_SYMBOLS,
+    # ),
     'regions': ResourceType(
         name='regions',
         domain='network',
@@ -650,7 +668,9 @@ RESOURCES = {
             "attributes": [],
             "enrollmentMethod": {"ott": True},
             "name": "Name"
-        }),
+        },
+        ziti=True,
+        ),
     'edge-routers': ResourceType(
         name='edge-routers',
         domain='network',
@@ -659,6 +679,7 @@ RESOURCES = {
         no_update_props=['registration'],
         create_responses=["ACCEPTED"],
         host=True,
+        ziti=True,
     ),
     'edge-router-policies': ResourceType(
         name='edge-router-policies',
@@ -673,6 +694,7 @@ RESOURCES = {
         mutable=True,
         embeddable=True,
         create_responses=["ACCEPTED"],
+        ziti=True,
     ),
     'service-policies': ResourceType(
         name='service-policies',
@@ -680,6 +702,7 @@ RESOURCES = {
         mutable=True,
         embeddable=True,
         create_responses=["ACCEPTED"],
+        ziti=True,
     ),
     'app-wans': ResourceType(
         name='app-wans',
@@ -695,6 +718,7 @@ RESOURCES = {
         mutable=True,
         embeddable=True,
         create_responses=["ACCEPTED"],
+        ziti=True,
     ),
     'posture-checks': ResourceType(
         name='posture-checks',
@@ -702,6 +726,7 @@ RESOURCES = {
         mutable=True,
         embeddable=True,
         create_responses=["ACCEPTED"],
+        ziti=True,
     ),
     'certificate-authorities': ResourceType(
         name='certificate-authorities',
@@ -709,6 +734,7 @@ RESOURCES = {
         mutable=True,
         embeddable=True,
         create_responses=["ACCEPTED"],
+        ziti=True,
     ),
     'config-types': ResourceType(
         name='config-types',
@@ -716,6 +742,7 @@ RESOURCES = {
         mutable=True,
         embeddable=True,
         create_responses=["ACCEPTED"],
+        ziti=True,
     ),
     'configs': ResourceType(
         name='configs',
@@ -723,6 +750,7 @@ RESOURCES = {
         mutable=True,
         embeddable=True,
         create_responses=["ACCEPTED"],
+        ziti=True,
     ),
     'terminators': ResourceType(
         name='terminators',
@@ -730,6 +758,7 @@ RESOURCES = {
         mutable=True,
         embeddable=True,
         create_responses=["ACCEPTED"],
+        ziti=True,
     ),
 }
 
@@ -756,8 +785,8 @@ def docstring_parameters(*args, **kwargs):
 
 
 RETRY_STRATEGY = Retry(
-    total=3,
-    status_forcelist=[413, 429, 503],
+    total=5,
+    status_forcelist=[403, 404, 413, 429, 503],  # The API responds 403 and 404 for not-yet-existing executions for some async operations
     method_whitelist=["HEAD", "GET", "PUT", "DELETE", "OPTIONS", "TRACE"],
     backoff_factor=1
 )
